# SCGT

## Santa Cruz Geographical Toolkit

This library provides convenience functions to read and write GeoTiff files, 
including iterating over their tiles. 

**Authors:**

* Luca de Alfaro (luca@ucsc.edu)
* Jasmine Tai (cjtai@ucsc.edu)
* Natalie Valett (nvalett@ucsc.edu)
* Coen Adler (ctadler@ucsc.edu)
* Artie Nazarov (anazarov@ucsc.edu)

This package provides utilities for working with geotiff files, including 
ways to read them (both all at once, and tile by tile), and to write them, 
and to create new geotiff files from scratch. 

For more details, see [the documentation](Documentation.md).

